<template>
  <PageWrapper
    :title="`送货单` + BILLCODE + `的资料`"
    content="这是送货单详情页面。"
    contentBackground
    @back="goBack"
  >
    <template #footer>
      <a-tabs default-active-key="detail" v-model:activeKey="currentKey" @tabClick="tabClkcallback">
        <a-tab-pane key="detail" tab="单据详情" />
        <a-tab-pane key="detailsn" tab="条码详情" />
      </a-tabs>
    </template>
    <div>
      <div v-if="currentKey == 'detail'">
        <BasicTable @register="detailTable">
          <template #toolbar>
            <a-button preIcon="OutR|svg" ghost color="success" @click="aoaToExceldtl"> 导出 </a-button>
          </template>
          <template #action="{ record }">
            <TableAction
              :actions="[
                {
                  icon: 'clarity:info-standard-line',
                  tooltip: '查看单据详情',
                  onClick: JumpSnDetail.bind(null, record),
                },
              ]"
            />
          </template>
        </BasicTable>
      </div>
      <div v-if="currentKey == 'detailsn'">
        <BasicTable @register="detailsnTable">
          <template #toolbar>
            <a-button preIcon="OutR|svg" ghost color="success" @click="aoaToExcelsn"> 导出 </a-button>
          </template>
        </BasicTable>
      </div>
    </div>
    <Loading :loading="compState.loading" :tip="compState.tip" />
  </PageWrapper>
</template>

<script lang="ts" setup>
import { aoaToSheetXlsx } from '/@/components/Excel';
  import { ref,reactive } from 'vue';
  import { useRoute } from 'vue-router';
  import { PageWrapper } from '/@/components/Page';
  import { useTabs } from '/@/hooks/web/useTabs';
  import { Tabs } from 'ant-design-vue';
  import { useGo } from '/@/hooks/web/usePage';
  //详情列表
  import { BasicTable, useTable, TableAction } from '/@/components/Table';
  import {
    getDeliveryDetailListByPage,
    getDeliveryDetailSNListByPage,
  } from '/@/api/tigerapi/wms/delivery';
  import { columns_D, columns_S, searchFormSchema_D, searchFormSchema_S } from './delivery.data';
  import { useI18n } from '/@/hooks/web/useI18n';
import { Loading } from '/@/components/Loading';
import { useMessage } from '/@/hooks/web/useMessage';
const { t: bt } = useI18n('');
const { createMessage } = useMessage();
const compState = reactive({
  absolute: false,
  loading: false,
  tip: '加载中...',
});
  const ATabs = ref(Tabs);
  const ATabPane = ref(Tabs.TabPane);
  const route = useRoute();
  var ITEM_CODE = ref('');
  const go = useGo();
  //获取JobId
  const BILLCODE = ref(route.params?.BillCode);
  const [detailTable, { getForm: DataDtl, getPaginationRef: DataPDtl }] = useTable({
    title: '单据详情列表',
    api: getDeliveryDetailListByPage,
    columns: columns_D,
    useSearchForm: true,
    showTableSetting: true,
    bordered: true,
    canResize:true,
    showIndexColumn: false,
    formConfig: {
      labelWidth: 120,
      schemas: searchFormSchema_D,
    },
    actionColumn: {
      width: 80,
      title: '操作',
      dataIndex: 'action',
      slots: { customRender: 'action' },
      fixed: 'right', //undefined,
    },
    searchInfo: { BILLCODE },
  });
  const [detailsnTable, { getForm: DataSn, getPaginationRef: DataPSn }] = useTable({
    title: '条码详情列表',
    api: getDeliveryDetailSNListByPage,
    columns: columns_S,
    formConfig: {
      labelWidth: 120,
      schemas: searchFormSchema_S,
      model: { ITEM_CODE: ITEM_CODE },
    },
    useSearchForm: true,
    searchInfo: { BILLCODE },
    showTableSetting: false,
    bordered: true,
    canResize:true,
    showIndexColumn: false,
  });


  let arrdtl: any[] = [];
let arrsn: any[] = [];
function aoaToExceldtl() {
  const totals = DataPDtl().total
  if (totals < 30000) {
    arrdtl = [];
    compState.loading = true;
    const col = DataDtl().getFieldsValue()
    col.BILLCODE = BILLCODE.value
    getDeliveryDetailListByPage(col).then((data) => {
      data.items.forEach(element => {
        let start = ''
        if(element.SOURCECODE==null){
          start = '待签收'
        }else{
          start = '已签收'
        }
        arrdtl.push({
          '送货单行号': element.LINE_NO,
          '物料编码': element.ITEM_CODE,
          '物料名称': element.ITEM_NAME,
          '操作时间': element.UPDATE_TIME,
          '状态': start,
          '数量': element.QTY,
          '计价数量': element.VALUATION_QTY,
        });
      });
      const arrHeader = columns_D.map((column) => column.title);
      const arrData = arrdtl.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致

      if (arrdtl.length < 30000) {
        aoaToSheetXlsx({
          data: arrData,
          header: arrHeader,
          filename: '送货单明细.xlsx',
        });
      } else {
        createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
    })
  }else{
    createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
  }
  compState.loading=false;
}

function aoaToExcelsn() {
  const totals = DataPSn().total
  if (totals < 30000) {
    arrsn = [];
    compState.loading = true;
    const col = DataSn().getFieldsValue()
    col.BILLCODE = BILLCODE.value
    getDeliveryDetailSNListByPage(col).then((data) => {
      data.items.forEach(element => {
        
        arrsn.push({
          '物料编码': element.ITEM_CODE,
          '修改时间':element.UPDATE_TIME,
          '小包条码': element.SMALL_BARCODE,
          '大包条码': element.BIG_BARCODE,
          '外箱条码': element.OUTER_BARCODE,
          '生产日期': element.PROD_DATE,
          '数量': element.QTY,
        });
      });
      const arrHeader = columns_S.map((column) => column.title);
      const arrData = arrsn.map((item) => {
        return Object.keys(item).map((key) => item[key]);
      });
      // 保证data顺序与header一致

      if (arrdtl.length < 30000) {
        aoaToSheetXlsx({
          data: arrData,
          header: arrHeader,
          filename: '送货单条码明细.xlsx',
        });
      } else {
        createMessage.error(bt('导出数据不能超过三万条，如需要更多的请联系管理员'));
      }
      compState.loading=false;
    })
  }
}

  // 此处可以得到用户ID
  //const BILLCODE = ref(route.params?.BILLCODE.split(',')[1]);
  var currentKey = ref('detail');
  const { setTitle } = useTabs();
  // TODO
  // 本页代码仅作演示，实际应当通过userId从接口获得用户的相关资料

  // 设置Tab的标题（不会影响页面标题）
  setTitle('详情：单据' + BILLCODE.value);

  // 页面左侧点击返回链接时的操作
  function goBack() {
    // 本例的效果时点击返回始终跳转到账号列表页，实际应用时可返回上一页
    go('/delivery');
  }
  const tabClkcallback = (val: string) => {
    if (val == 'detail') {
      ITEM_CODE.value = '';
    }
  };
  function JumpSnDetail(record: Recordable) {
    currentKey.value = 'detailsn';
    ITEM_CODE.value = record.ITEM_CODE;
  }
</script>
